@@ -57,8 +57,6 @@ enum {
 	NUM_COLUMNS
 };
 
-static GtkVBoxClass *parent_class;
-
 G_DEFINE_TYPE (EvSidebarThumbnails, ev_sidebar_thumbnails, GTK_TYPE_VBOX);
 
 #define EV_SIDEBAR_THUMBNAILS_GET_PRIVATE(object) \
@@ -76,7 +74,7 @@ ev_sidebar_thumbnails_destroy (GtkObject *object)
 		priv->idle_id = 0;
 	}
 
-	GTK_OBJECT_CLASS (parent_class)->destroy (object);
+	GTK_OBJECT_CLASS (ev_sidebar_thumbnails_parent_class)->destroy (object);
 }
 
 static void
@@ -88,8 +86,6 @@ ev_sidebar_thumbnails_class_init (EvSidebarThumbnailsClass *ev_sidebar_thumbnail
 	g_object_class = G_OBJECT_CLASS (ev_sidebar_thumbnails_class);
 	gtk_object_class = GTK_OBJECT_CLASS (ev_sidebar_thumbnails_class);
 
- 	parent_class = g_type_class_peek_parent (ev_sidebar_thumbnails_class);
-
 	gtk_object_class->destroy = ev_sidebar_thumbnails_destroy;
 
 	g_type_class_add_private (g_object_class, sizeof (EvSidebarThumbnailsPrivate));
@@ -322,6 +318,8 @@ ev_sidebar_thumbnails_select_page (EvSidebarThumbnails *sidebar,
 
 	if (path) {
 		gtk_tree_selection_select_path (selection, path);
+		gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (sidebar->priv->tree_view),
+					      path, NULL, FALSE, 0.0, 0.0);
 		gtk_tree_path_free (path);	
 	}
 }
